## How to contribute

Thank you for considering contributing to Trafilatura! Your contributions make the software and its documentation better.


There are many ways to contribute, you could:

  * Improve the documentation: Write tutorials and guides, correct mistakes, or translate existing content.
  * Find bugs and submit bug reports: Help making Trafilatura a robust and versatile tool.
  * Submit feature requests: Share your feedback and suggestions.
  * Write code: Fix bugs or add new features.


Here are some important resources:

  * [List of currently open issues](https://github.com/adbar/trafilatura/issues) (no pretention to exhaustivity!)
  * [Roadmap and milestones](https://github.com/adbar/trafilatura/milestones)
  * [How to Contribute to Open Source](https://opensource.guide/how-to-contribute/)


## Submitting changes

Please send a [GitHub Pull Request to trafilatura](https://github.com/adbar/trafilatura/pull/new/master) with a clear list of what you have done (read more about [pull requests](http://help.github.com/pull-requests/)).

**Working on your first Pull Request?** See this tutorial: [How To Create a Pull Request on GitHub](https://www.digitalocean.com/community/tutorials/how-to-create-a-pull-request-on-github)


A special thanks to all the [contributors](https://github.com/adbar/trafilatura/graphs/contributors) who have played a part in Trafilatura.



## Testing and evaluating the code

Here is how you can run the tests if you wish to correct the errors and further improve the code:

- Run `pytest` from trafilatura's directory, or select a particular test suite, for example `realworld_tests.py`, and run `pytest realworld_tests.py` or simply `python3 realworld_tests.py`
- Check how it performs on the benchmark in `tests/eval/` by running `tests/comparison_small.py`

See also the [tests Readme](tests/README.rst) for more information on the evaluation.



For further questions you can contact me by way of [GitHub issues](https://github.com/adbar/trafilatura/issues), [X](https://x.com/adbarbaresi) or [E-Mail](https://adrien.barbaresi.eu/).

Thanks,

Adrien
